<?php

namespace EuKit\Base;

use EuKit\Base\Interfaces\ViewModel;
use Infomaker\Everyware\Base\Menus;
use Infomaker\Everyware\Base\Models\Post;
use Infomaker\Everyware\Base\OpenContent\OpenContentProvider;
use OcArticle;

/**
 * Class ArticlePageTemplate
 * @package EuKit\Base
 */
class ArticlePageTemplate implements ViewModel
{
    /**
     * @var NewsMLArticle
     */
    private $article;

    public function __construct(NewsMLArticle $article)
    {
        $this->article = $article;
    }

    public function getViewData(): array
    {
        $articleBody = $this->article->getParsedBody();
        $articleBodyPresentation = new ArticleBodyPresentation($this->article);

        $main_menu = Menus::getFromLocation('main-menu');
        $top_menu = Menus::getFromLocation('top-menu');

        $articleTeaser = $this->article->getNewsMLTeaser();

        $image = $articleTeaser->getImage();
        if($image !== null){
            $image->set('text', $articleTeaser->title);
            $image = new Image($image);
        }

        return array_replace($this->article->toArray(), [
            'menu' => $main_menu ? $main_menu->items() : [],
            'topmenu' => $top_menu ? $top_menu->items() : [],
            'teaserImage' => $image ? $image->getViewData() : null,
            'body' => $articleBody->generateContent($articleBodyPresentation),
            'relatedArticles' => $articleBody->allOfType('x-im/articlex'),
            'authors' => $this->article->getAuthors()->toArray()
        ]);

    }

    public static function createFromPost(Post $post)
    {
        $uuid = $post->getMeta('oc_uuid');

        $provider = OpenContentProvider::setup();
        $provider->setPropertyMap('Article');
        $article = $provider->getObject($uuid);

        if ($article instanceof OcArticle) {
            return new static(NewsMLArticle::createFromOcArticle($article));
        }

        return new static(new NewsMLArticle($article));
    }
}
